@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 """
 Ditz command handler.
 """
@@ -136,6 +138,14 @@ class DitzCmd(Cmd):
                 issuetype = types[reply[0]]
                 break
 
+        choices = self.db.components
+        if len(choices) >= 2:
+            comp = self.getchoice("component", choices)
+            if not comp:
+                return
+        else:
+            comp = None
+
         release = None
         releases = self.db.project.releases
         choices = [rel.name for rel in releases if rel.status == UNRELEASED]
@@ -158,7 +168,7 @@ class DitzCmd(Cmd):
 
         issue = self.db.add_issue(title, desc, type=issuetype,
                                   reporter=reporter, release=release,
-                                  comment=comment)
+                                  component=comp, comment=comment)
 
         print "Added issue", self.db.issue_name(issue)
         return True
@@ -284,6 +294,8 @@ class DitzCmd(Cmd):
             return
 
         self.db.set_release(issue, release, comment=comment)
+        print "Assigned", name, "to", release
+
         return True
 
     def do_changelog(self, arg):
@@ -476,7 +488,9 @@ class DitzCmd(Cmd):
             return
 
         if not comp:
-            choices.remove(issue.component)
+            if issue.component in choices:
+                choices.remove(issue.component)
+
             comp = self.getchoice("component", choices)
             if not comp:
                 return
@@ -801,7 +815,7 @@ class DitzCmd(Cmd):
             lines = []
             while True:
                 line = self.getline(prompt, interrupt=False)
-                if not line or line == endchar:
+                if line is None or line == endchar:
                     return "\n".join(lines)
 
                 lines.append(line)
